CliError

Enum CliError 

pub enum CliError {
Show 22 variants InvalidArgument { arg: String, value: String, reason: String, hint: Option<String>, }, MissingArgument { arg: String, context: String, }, ConflictingArguments { arg1: String, arg2: String, reason: String, }, InvalidArgumentCombination { args: Vec<String>, reason: String, }, ConfigIo { path: PathBuf, message: String, }, ConfigParse { path: PathBuf, message: String, line: Option<usize>, }, ConfigValue { path: PathBuf, key: String, value: String, reason: String, }, RomLoad { path: PathBuf, message: String, }, RomNotFound { path: PathBuf, }, RomInvalid { path: PathBuf, reason: String, }, SavestateLoad { source: String, message: String, }, SavestateSave { destination: String, message: String, }, SavestateInvalid { source: String, reason: String, }, InvalidAddress { address: String, reason: String, }, InvalidMemoryRange { range: String, reason: String, hint: Option<String>, }, MemoryAccess { operation: String, address: u16, message: String, }, Execution { message: String, cycles: Option<u128>, frames: Option<u64>, }, InvalidStopCondition { condition: String, reason: String, hint: Option<String>, }, OutputWrite { destination: String, message: String, }, InvalidOutputFormat { format: String, valid_formats: Vec<String>, }, Io { operation: String, message: String, }, Internal { message: String, },
}
Comprehensive error type for CLI operations.

This enum covers all possible error conditions in the CLI module, providing structured information for error handling and reporting.

Variants



InvalidArgument

Invalid argument value

Fields

value: String
reason: String


MissingArgument

Missing required argument

Fields

context: String


ConflictingArguments

Conflicting arguments specified

Fields

arg1: String
arg2: String
reason: String


InvalidArgumentCombination

Invalid combination of arguments

Fields

args: Vec<String>
reason: String


ConfigIo

Failed to read config file

Fields

path: PathBuf
message: String


ConfigParse

Failed to parse config file

Fields

path: PathBuf
message: String


ConfigValue

Invalid config value

Fields

path: PathBuf
value: String
reason: String


RomLoad

Failed to load ROM

Fields

path: PathBuf
message: String


RomNotFound

ROM not found

Fields

path: PathBuf


RomInvalid

Invalid ROM format

Fields

path: PathBuf
reason: String


SavestateLoad

Failed to load savestate

Fields

source: String
message: String


SavestateSave

Failed to save savestate

Fields

destination: String
message: String


SavestateInvalid

Invalid savestate format

Fields

source: String
reason: String


InvalidAddress

Invalid memory address

Fields

address: String
reason: String


InvalidMemoryRange

Invalid memory range

Fields

range: String
reason: String


MemoryAccess

Memory access error

Fields

operation: String
address: u16
message: String


Execution

Execution error

Fields

message: String
cycles: Option<u128>
frames: Option<u64>


InvalidStopCondition

Invalid stop condition

Fields

condition: String
reason: String


OutputWrite

Failed to write output

Fields

destination: String
message: String


InvalidOutputFormat

Invalid output format

Fields

format: String
valid_formats: Vec<String>


Io

I/O error

Fields

operation: String
message: String


Internal

Internal error (should not happen)

Fields

message: String

Implementations

Source

impl CliError

pub fn invalid_arg( arg: impl Into<String>, value: impl Into<String>, reason: impl Into<String>, ) -> Self

Create an invalid argument error.

pub fn invalid_arg_with_hint( arg: impl Into<String>, value: impl Into<String>, reason: impl Into<String>, hint: impl Into<String>, ) -> Self

Create an invalid argument error with a hint.

pub fn missing_arg(arg: impl Into<String>, context: impl Into<String>) -> Self

Create a missing argument error.

pub fn conflicting_args( arg1: impl Into<String>, arg2: impl Into<String>, reason: impl Into<String>, ) -> Self

Create a conflicting arguments error.

pub fn config_io(path: impl Into<PathBuf>, err: impl Display) -> Self

Create a config I/O error.

pub fn config_parse(path: impl Into<PathBuf>, err: impl Display) -> Self

Create a config parse error.

pub fn invalid_memory_range( range: impl Into<String>, reason: impl Into<String>, ) -> Self

Create an invalid memory range error.

pub fn invalid_address( address: impl Into<String>, reason: impl Into<String>, ) -> Self

Create an invalid address error.

pub fn savestate_load(source: impl Into<String>, err: impl Display) -> Self

Create a savestate load error.

pub fn savestate_save(destination: impl Into<String>, err: impl Display) -> Self

Create a savestate save error.

pub fn execution(message: impl Into<String>) -> Self

Create an execution error.

pub fn invalid_stop_condition( condition: impl Into<String>, reason: impl Into<String>, ) -> Self

Create an invalid stop condition error.

pub fn output_write(destination: impl Into<String>, err: impl Display) -> Self

Create an output write error.

pub fn io(operation: impl Into<String>, err: impl Display) -> Self

Create an I/O error.

pub fn internal(message: impl Into<String>) -> Self

Create an internal error.

pub fn is_user_error(&self) -> bool

Check if this is a user error (invalid input).

pub fn is_io_error(&self) -> bool

Check if this is an I/O error.

pub fn exit_code(&self) -> u8

Get the exit code for this error.