pub struct MemoryDump {
pub mem_type: MemoryType,
pub start_addr: u16,
pub end_addr: u16,
pub data: Vec<u8>,
pub interpreted_oam: Option<InterpretedOam>,
pub interpreted_nametables: Option<InterpretedNametables>,
}Expand description
A memory dump with metadata and optional interpreted data.
This is the common data structure passed to all formatters. For OAM and nametable dumps, interpreted data is also included.
Fields
mem_type: MemoryTypeType of memory (cpu, ppu, oam, nametables)
start_addr: u16Start address
end_addr: u16End address
data: Vec<u8>Raw memory bytes
interpreted_oam: Option<InterpretedOam>Interpreted OAM data (only for OAM dumps)
interpreted_nametables: Option<InterpretedNametables>Interpreted nametable data (only for nametable dumps)
Implementations
Sourceimpl MemoryDump
impl MemoryDump
Sourcepub fn new(mem_type: MemoryType, start_addr: u16, data: Vec<u8>) -> Self
pub fn new(mem_type: MemoryType, start_addr: u16, data: Vec<u8>) -> Self
Create a new memory dump
Sourcepub fn nametables(data: Vec<u8>) -> Self
pub fn nametables(data: Vec<u8>) -> Self
Create nametables memory dump with interpreted data.
Sourcepub fn palette_ram(data: Vec<u8>) -> Self
pub fn palette_ram(data: Vec<u8>) -> Self
Create palette RAM memory dump. Palette RAM is 32 bytes at PPU addresses $3F00-$3F1F.