ExecutionConfig

Struct ExecutionConfig 

pub struct ExecutionConfig {
    pub stop_conditions: Vec<StopCondition>,
    pub stop_on_halt: bool,
    pub trace_path: Option<PathBuf>,
    pub verbose: bool,
}
Configuration for an execution run.

This struct is designed to be constructed either from CLI arguments or programmatically when using the crate as a library.

Fields

stop_conditions: Vec<StopCondition>

Stop conditions (first one met will stop execution)

stop_on_halt: bool

Whether to stop on any HLT instruction

trace_path: Option<PathBuf>

Path to trace log file (if any)

verbose: bool

Verbose output

Implementations

Source

impl ExecutionConfig

pub fn new() -> Self

Create a new empty execution config

pub fn with_stop_condition(self, condition: StopCondition) -> Self

Add a stop condition

pub fn with_cycles(self, cycles: u128) -> Self

Set stop after N cycles

pub fn with_frames(self, frames: u64) -> Self

Set stop after N frames

pub fn with_pc_breakpoint(self, addr: u16) -> Self

Set stop when PC equals address

pub fn with_breakpoint(self, addr: u16) -> Self

Add a breakpoint (alias for with_pc_breakpoint)

pub fn with_memory_watch(self, addr: u16, access_type: MemoryAccessType) -> Self

Add a memory watchpoint

pub fn with_trace(self, path: PathBuf) -> Self

Set trace log path

pub fn with_verbose(self, verbose: bool) -> Self

Enable verbose output

pub fn with_stop_on_halt(self, stop: bool) -> Self

Enable stop on HLT

Source

impl ExecutionConfig

pub fn from_cli_args(args: &CliArgs) -> Self

Build execution config from CLI arguments